@@ -2,9 +2,10 @@ import re
 import imaplib
 
 from mailbox import Mailbox
-from utf import encode as encode_utf7, decode as decode_utf7
+from gmail_client.codecs.utf7 import encode as encode_utf7, decode as decode_utf7
 from exceptions import *
 
+
 class Gmail():
     # GMail IMAP defaults
     GMAIL_IMAP_HOST = 'imap.gmail.com'
