@@ -1,5 +1,5 @@
 from message import Message
-from utf import encode as encode_utf7, decode as decode_utf7
+from gmail_client.codecs.utf7 import encode as encode_utf7, decode as decode_utf7
 
 
 class Mailbox():
