@@ -3,9 +3,10 @@ import email
 import re
 import time
 import os
-from email.header import decode_header
 from imaplib import ParseFlags
 
+from gmail_client.codecs import decode_email_header
+
 
 def parse_flags(headers):
     """
@@ -66,7 +67,6 @@ class Attachment(object):
         self.content = content
         self.size = 0 if content is None else len(self.content)
 
-
     def save(self, path=None):
         if path is None:
             # Save as name of attachment if there is no path specified
@@ -96,11 +96,10 @@ class ParsedEmail(object):
         content_disposition = p.get("Content-Disposition", None)
         filename = p.get_filename()
         
-        if filename is not None and content_disposition is not None:
-            dispositions = content_disposition.strip().split(";")
-
-            if dispositions[0].lower() in ["attachment", "inline"]:
-                return True
+        if filename is not None \
+                or (content_disposition is not None and
+                    content_disposition.find('attachment')):
+            return True
         
         return False
 
@@ -131,7 +130,7 @@ class ParsedEmail(object):
             return self.parse_message(p)
 
     def parse_attachment(self, message_part):
-        a = Attachment(decode_header(message_part.get_filename())[0][0],
+        a = Attachment(decode_email_header(message_part.get_filename()),
                        message_part.get_content_type(),
                        message_part.get_payload(decode=True))
 
